@@ -1,4 +1,4 @@
-%% Copyright (C) 2014-2016, 2018 Colin B. Macdonald
+%% Copyright (C) 2014-2016, 2018-2019 Colin B. Macdonald
 %% Copyright (C) 2014-2015 Andrés Prieto
 %%
 %% This file is part of OctSymPy.
@@ -177,80 +177,14 @@ function [soln,classify] = dsolve(ode,varargin)
     classify='';
   end
 
-  % Newer Sympy can do IC/BC itself
-  if (python_cmd ('return Version(spver) > Version("1.1.1")'))
-    cmd = { 'ode=_ins[0]; ics=_ins[1:]'
-            '# convert our input to a dict'
-            'ics2 = {}'
-            'for s in ics:'
-            '    ics2[s.lhs] = s.rhs'
-            'sol = sp.dsolve(ode, ics=ics2)'
-            'return sol,' };
-    soln = python_cmd (cmd, ode, varargin{:});
-    return
-  end
-
-
-  % FIXME: the initial/boundary conditions admit parameters
-  %        but only on their values (not at the evaluation point)
-
-  % FIXME: it is not currently supported a list of boundary/initial conditions
-  if (isscalar(ode) && nargin>=2)
   cmd = { 'ode=_ins[0]; ics=_ins[1:]'
-          'sol=sp.dsolve(ode)'
-          'x=list(ode.free_symbols)[0]'
-          'ic_eqs=[]'
-          'for ic in ics:'
-          '    funcarg=ic.lhs'
-          '    if isinstance(funcarg, sp.Subs):'
-          '        x0=funcarg.point[0]'
-          '        dorder=sp.ode_order(funcarg.expr, x)'
-          '        dsol_eq=sp.Eq(sp.diff(sol.lhs,x,dorder),sp.diff(sol.rhs,x,dorder))'
-          '        dy_at_x0=funcarg.expr.subs(x,x0)'
-          '        ic_eqs.append(dsol_eq.subs(x,x0).subs(dy_at_x0,ic.rhs))'
-          '    elif isinstance(funcarg, sp.function.AppliedUndef):'
-          '        x0=funcarg.args[0]'
-          '        ic_eqs.append(sol.subs(x,x0).subs(funcarg,ic.rhs))'
-          'sol_C=sp.solve(ic_eqs)'
-          'if type(sol_C)==dict:'
-          '    sol_final=sol.subs(sol_C)'
-          'elif type(sol_C)==list:'
-          '    sol_final=[]'
-          '    for c in sol_C:'
-          '        sol_final.append(sol.subs(c))'
-          'return sol_final,'};
-
-    soln = python_cmd (cmd, ode, varargin{:});
-
-  % FIXME: only solve initial-value problems involving linear systems
-  %        of first order ODEs with constant coefficients (a unique
-  %        solution is expected)
-  elseif(~isscalar(ode) && nargin>=2)
-
-  cmd = { 'ode=_ins[0]; ics=_ins[1:]'
-          'sol=sp.dsolve(ode)'
-          'x=list(ode[0].free_symbols)[0]'
-          'ic_eqs=[]'
-          'for solu in sol:'
-          '    ic_eqs.append(solu)'
-          '    for ic in ics:'
-          '        funcarg=ic.lhs'
-          '        if isinstance(funcarg, sp.function.AppliedUndef):'
-          '            x0=funcarg.args[0]'
-          '            ic_eqs[-1]=ic_eqs[-1].subs(x,x0).subs(funcarg,ic.rhs)'
-          'sol_C=sp.solve(ic_eqs)'
-          'sol_final=[]'
-          'for y in sol:'
-          '    sol_final.append(y.subs(sol_C))'
-          'return sol_final,'};
-
-    soln = python_cmd (cmd, ode, varargin{:});
-
-  elseif(nargin==1)
-
-    soln = python_cmd ('return sp.dsolve(*_ins),', ode);
-
-  end
+          '# convert our input to a dict'
+          'ics2 = {}'
+          'for s in ics:'
+          '    ics2[s.lhs] = s.rhs'
+          'sol = sp.dsolve(ode, ics=ics2)'
+          'return sol,' };
+  soln = python_cmd (cmd, ode, varargin{:});
 end
 
 
@@ -387,9 +321,7 @@ end
 %! assert (isequal (diff(Y) - (Y - t - 3), 0))
 
 %!test
-%! if (python_cmd ('return Version(spver) > Version("1.1.1")'))
 %! syms f(x) a b
 %! de = diff(f, x) == 4*f;
 %! s = dsolve(de, f(a) == b);
 %! assert (isequal (subs(rhs(s), x, a), b))
-%! end
