@@ -1,5 +1,5 @@
 %% Copyright (C) 2015 Carnë Draug
-%% Copyright (C) 2016 Colin B. Macdonald
+%% Copyright (C) 2016, 2018 Colin B. Macdonald
 %%
 %% This file is part of OctSymPy.
 %%
@@ -39,9 +39,15 @@
 %% Keywords: symbolic, constants
 
 function g = catalan ()
+
+  if (nargin ~= 0)
+    print_usage ();
+  end
+
   g = python_cmd ('return sympy.S.Catalan,');
 end
 
 
+%!error <Invalid> catalan (sym(1))
 %!assert (double (catalan ()) > 0.915965594177)
 %!assert (double (catalan ()) < 0.915965594178)
