@@ -22,6 +22,12 @@
 %% @defunx evalpy (@var{cmd}, @var{x}, @var{y}, @dots{})
 %% Run Python code, automatically transferring results.
 %%
+%% @strong{Note} this function is @emph{deprecated}.
+%% @example
+%% @comment doctest: -TEXINFO_SKIP_BLOCKS_WO_OUTPUT
+%% s = warning ('off', 'OctSymPy:deprecated');
+%% @end example
+%%
 %% Examples:
 %% @example
 %% @group
@@ -65,6 +71,7 @@
 %%   @print{} ??? '_y' undefined near line 1 column 1
 %% z_
 %%   @print{} ??? 'z_' undefined near line 1 column 1
+%% warning (s);
 %% @end group
 %% @end example
 %%
@@ -86,7 +93,7 @@
 %% @itemize
 %% @item if you assign to @var{x} but don't change its value,
 %%   it will not be assigned to and will not appear in the
-%%   Variables effected:" list.
+%%   ``Variables effected'' list.
 %% @item using print is probably a bad idea.  For now, use
 %%   @code{dbout(x)} to print @code{x} to stderr which should
 %%   appear in the terminal (FIXME: currently broken on windows).
@@ -104,6 +111,8 @@
 
 function evalpy(cmd, varargin)
 
+  warning('OctSymPy:deprecated', 'evalpy is deprecated')
+
   %% import variables
   % use name of input if it has one, also i0, i1, etc
   s = {};
@@ -202,23 +211,30 @@ end
 
 
 %!test
+%! s = warning ('off', 'OctSymPy:deprecated');
 %! x = 6;
 %! evalpy('y = 2*x;;', x);
 %! assert( y == 12 )
+%! warning (s)
 
 %!test
+%! s = warning ('off', 'OctSymPy:deprecated');
 %! x = 6;
 %! evalpy('y = 2*x; x = 10; z = 3*x;;', x);
 %! assert( isequal( [x y z], [10 12 30] ))
+%! warning (s)
 
 %% underscore variables not returned
 %!test
+%! s = warning ('off', 'OctSymPy:deprecated');
 %! evalpy('_y = 42; x_ = 42');
 %! assert( ~exist('_y', 'var'))
 %! assert( ~exist('x_', 'var'))
+%! warning (s)
 
 %!test
+%! s = warning ('off', 'OctSymPy:deprecated');
 %! evalpy('_y = "GNU Octave Rocks"; z = _y.split();;');
 %! assert( iscell(z) )
 %! assert( isequal (z, {'GNU', 'Octave','Rocks'} ))
-
+%! warning (s)
