@@ -1,4 +1,5 @@
-%% Copyright (C) 2014-2016 Colin B. Macdonald
+%% Copyright (C) 2014-2018 Colin B. Macdonald
+%% Copyright (C) 2018 Mike Miller
 %%
 %% This file is part of OctSymPy.
 %%
@@ -44,10 +45,11 @@ function [A, info] = python_ipc_popen2(what, cmd, varargin)
   if (strcmp(what, 'reset'))
     if (~isempty(pid))
       if (verbose)
-        disp('Closing the Python pipe...');
+        disp ('Closing the Python communications link.')
       end
     end
     if (~isempty(fin))
+      % produces a single newline char: not sure why
       t = fclose(fin); fin = [];
       waitpid(pid);
       pid = [];
@@ -70,36 +72,21 @@ function [A, info] = python_ipc_popen2(what, cmd, varargin)
 
   if isempty(pid)
     if (verbose)
-      fprintf('OctSymPy v%s: this is free software without warranty, see source.\n', ...
-              sympref('version'))
-      disp('Initializing communication with SymPy using a popen2() pipe.')
+      fprintf ('Symbolic pkg v%s: ', sympref('version'))
     end
     pyexec = sympref('python');
-    assert_have_python_and_sympy(pyexec)
 
-    if (ispc() && ~isunix() && compare_versions (OCTAVE_VERSION (), '4.0.2', '<='))
-      if (verbose)
-        disp('Using winwrapy.bat workaround for bug #43036 (Octave <= 4.0.2, on Windows)')
-      end
-      [fin, fout, pid] = popen2 ('winwrapy.bat', pyexec);
-    else
-      [fin, fout, pid] = popen2 (pyexec, '-i');
-    end
+    assert_have_python_and_sympy (pyexec)
 
-    if (verbose)
-      fprintf('Some output from the Python subprocess (pid %d) might appear next.\n', pid)
-      %fprintf('Technical details: fin = %d, fout = %d, pid = %d.\n', fin, fout, pid)
-    end
+    % formatting matters
+    args = {'-i', '-c', 'import sys; sys.ps1=''''; sys.ps2='''''};
+    [fin, fout, pid] = popen2 (pyexec, args);
     fflush (stdout);
 
     if (pid < 0)
       error('popen2() failed');
     end
 
-    % repeated from python_header.py: kill prompt ASAP
-    fprintf (fin, 'import sys\nsys.ps1 = ""; sys.ps2 = ""\n\n')
-    fflush(fin);
-
     headers = python_header();
     fputs (fin, headers);
     fprintf (fin, '\n\n');
@@ -115,14 +102,9 @@ function [A, info] = python_ipc_popen2(what, cmd, varargin)
         'ipc_popen2: something wrong? timed out starting python')
     end
     A = extractblock(out);
-    fprintf('\n');  % needed even if not verbose
     if (iscell(A) && strcmp(A{1}, 'Communication established.'))
       if (verbose)
-        disp(['OctSymPy: ' A{1} '  SymPy v' A{2} '.']);
-        % on unix we're seen this on stderr
-        if (ispc() && ~isunix())
-          disp(['Python ' strrep(A{3}, newl, '')])
-        end
+        fprintf ('Python communication link active, SymPy v%s.\n', A{2});
       end
     elseif (iscell(A) && strcmp(A{1}, 'INTERNAL_PYTHON_ERROR'))
       info.raw = out;
@@ -162,9 +144,13 @@ function [A, info] = python_ipc_popen2(what, cmd, varargin)
     % the pipe should still be in working order, no need to reset
     return
   else
+    disp ('Debugging output:')
     A
     out
-    error('ipc_popen2: something unexpected happened sending variables to python')
+    msg = ['ipc_popen2: something unexpected happened sending variables to python.\n' ...
+           '    This can happen after interrupting with Ctrl-C.\n' ...
+           '    Do "sympref reset" and try your command again.'];
+    error (sprintf (msg))
   end
 
   % The number of lines of code before the command itself: because
