@@ -17,16 +17,28 @@
 %% If not, see <http://www.gnu.org/licenses/>.
 
 %% -*- texinfo -*-
-%% @deftypefn  {Function File} {@var{L}} valid_sym_assumptions ()
-%% @deftypefnx {Function File} {} syms
+%% @defun valid_sym_assumptions ()
 %% Return list of valid assumptions.
 %%
-%% @end deftypefn
+%% @end defun
+
+%% Reference: http://docs.sympy.org/dev/modules/core.html
+
+%% FIXME: Maybe in the future remove this file and replace with something else.
+
 
 function L = valid_sym_assumptions()
 
-  L = {'real', 'positive', 'negative', 'integer', 'even', 'odd', ...
-       'rational', 'finite'};
+  persistent List
+
+  if (isempty(List))
+
+    cmd = {'from sympy.core.assumptions import _assume_defined'
+           'return list(_assume_defined),'};
+    List = python_cmd(cmd);
+
+  end
+
+  L = List;
 
 end
-
